@@ -17,7 +17,7 @@ def has_new_mail(api) -> int:
 
     # log.showValue(
     #     api.config,
-    #     log.Level.INFO,
+    #     log.level.INFO,
     #     [
     #         i18n.PTT,
     #         i18n.Msg
@@ -27,10 +27,8 @@ def has_new_mail(api) -> int:
 
     cmd_list = []
     cmd_list.append(command.GoMainMenu)
-    cmd_list.append('M')
-    cmd_list.append(command.Enter)
-    cmd_list.append('R')
-    cmd_list.append(command.Enter)
+    cmd_list.append(command.Ctrl_Z)
+    cmd_list.append('m')
     cmd_list.append('1')
     cmd_list.append(command.Enter)
     cmd_list.append('$')
@@ -41,14 +39,13 @@ def has_new_mail(api) -> int:
             i18n.MailBox,
             screens.Target.InMailBox,
             break_detect=True,
-            log_level=log.Level.DEBUG
+            log_level=log.level.DEBUG
         )
     ]
 
     api.connect_core.send(
         cmd,
         target_list,
-        screen_timeout=api.config.screen_long_timeout
     )
 
     ori_screen = api.connect_core.get_screen_queue()[-1]
